#!/usr/bin/perl
# skel_getversionnumbers.pl
#                           RBLandau 20071005
# Get the highest version numbers of all files mentioned in the input file

use newtrace; 

defined($ARGV[2-1]) || 
    die "Usage: skel_getversionnumbers.pl version-input-file dirname   ";

# First arg is input file with names and versions
if (defined($ARGV[1-1]))
{
    $sVerFileIn = $ARGV[1-1];
} else
{ 
    $sVerFileIn = "xmlfileversions_in.txt";
}
open( VERIN, "<$sVerFileIn") ||
    die "Error: cannot open file $sVerFileIn: $!\n";
while(<VERIN>)
{
    next if /^\s*#/;
    next if /^\s*$/;
    chomp;
    tr/\r\n//;      # needed for CygWin, chomp does not remove CR
    $sLine = $_;
    newtrace::trace(1,"proc linein|$sLine|");
    $sFileName = "";
    ($sFileName,$sFileVersion) = $sLine =~
        /^VER_([A-Za-z0-9]+)\s*=\s*([A-Za-z0-9]+)$/i;
    newtrace::trace(1,"proc verin file|$sFileName| ver|$sFileVersion|");
    if ($sFileName)
    {
        # Save root filename and version number
        $hNam2Ver{uc($sFileName)} = $sFileVersion; 
    }
}

# Second arg is directory in which to search for newer versions
# of the files named in the input file
$sDirName = $ARGV[2-1];
opendir(DIR, $sDirName) or die "can't opendir $sDirName: $!";
while (defined($sFileName = readdir(DIR))) 
{
    # Pull out the root name and version number in the name
    # format = <rootname>_v<number>.xml
    ($sRootName,$sVerNum) = $sFileName =~
        /^([^_]+)_v(.*)\.xml$/i;
    newtrace::trace(3,"proc file|$sFileName| root|$sRootName| ver|$sVerNum|");
    $sFindName = uc($sRootName);
    $sFoundVer = $hNam2Ver{$sFindName};
    if ($sFoundVer)
    {
        newtrace::trace(1,"proc found name|$sFindName| ver|$sFoundVer|");
        if ($sFoundVer < $sVerNum)
        {
            $hNam2Ver{$sFindName} = $sVerNum;
            newtrace::trace(1,"proc replace name|$sFindName| ver|$sVerNum|");
        }
    }
#    newtrace::trace(1,"");
}
closedir(DIR);

# Now recreate the input file with maybe new version numbers

for $sRootName (sort keys %hNam2Ver)
{
    print "VER_$sRootName = $hNam2Ver{$sRootName}\n";
}


